**Pyaasp**
======

## Description

**Pyaasp** is a python package for Advanced Array Seismic data Processing. The package contains a bunch of advanced seismic data analysis algorithms and hopefully has a wide range of applications in seismology. More examples will be continuously updated. 

## Reference
Chen et al., 2022, Pyaasp, In preparation. 

BibTeX:

	@article{aasp,
	  title={TBD},
	  author={Authors},
	  journal={TBD},
	  volume={1},
	  number={1},
	  pages={1-10},
	  year={2022}
	}

-----------
## Copyright
    Initial version: Yangkang Chen (chenyk2016@gmail.com), 2021-2022
	Later version: pyaasp developing team, 2022-present
-----------

## License
    GNU General Public License, Version 3
    (http://www.gnu.org/copyleft/gpl.html)   

-----------

## Install

git clone https://github.com/chenyk1990/pyaasp

cd pyaasp

pip install -v -e .

or

pip install pyaasp

-----------
## Examples
    The "demo" directory contains all runable scripts to demonstrate different applications of pyaasp. 

-----------
## Dependence Packages
* scipy 

* numpy 

* matplotlib

-----------
## Development
    The development team welcomes voluntary contributions from any open-source enthusiast. 
    If you want to make contribution to this project, feel free to contact the development team. 

-----------
## Contact
    Regarding any questions, bugs, developments, collaborations, please contact  
    Yangkang Chen
    chenyk2016@gmail.com

-----------


